Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(101)

Unified Diff: components/password_manager/sync/browser/sync_credentials_filter_unittest.cc

Issue 1668523002: [Password Manager] Switch password manager code to use the Feature framework. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addresses the review inputs. Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/sync/browser/sync_credentials_filter_unittest.cc
diff --git a/components/password_manager/sync/browser/sync_credentials_filter_unittest.cc b/components/password_manager/sync/browser/sync_credentials_filter_unittest.cc
index cc43857f56f56f3d40e60d7a36ccf667d97bc4f3..a49daeede85d356d54c5b2c02465f06a84d59f75 100644
--- a/components/password_manager/sync/browser/sync_credentials_filter_unittest.cc
+++ b/components/password_manager/sync/browser/sync_credentials_filter_unittest.cc
@@ -9,13 +9,13 @@
#include "base/bind.h"
#include "base/bind_helpers.h"
-#include "base/command_line.h"
#include "base/macros.h"
#include "base/test/histogram_tester.h"
#include "base/test/user_action_tester.h"
#include "components/autofill/core/common/password_form.h"
+#include "components/password_manager/core/browser/password_manager_test_utils.h"
#include "components/password_manager/core/browser/stub_password_manager_client.h"
-#include "components/password_manager/core/common/password_manager_switches.h"
+#include "components/password_manager/core/common/password_manager_features.h"
#include "components/password_manager/sync/browser/sync_username_test_base.h"
#include "testing/gtest/include/gtest/gtest.h"
@@ -135,9 +135,10 @@ TEST_F(CredentialsFilterTest, FilterResults_AllowAll) {
}
TEST_F(CredentialsFilterTest, FilterResults_DisallowSyncOnReauth) {
- base::CommandLine* command_line = base::CommandLine::ForCurrentProcess();
- command_line->AppendSwitch(
- switches::kDisallowAutofillSyncCredentialForReauth);
+ // Only 'protect-sync-credential-on-reauth' feature is kept enabled, fill the
+ // sync credential everywhere but on reauth.
+ EnableFeature(features::kProtectSyncCredential, false, false);
+ EnableFeature(features::kProtectSyncCredentialOnReauth, true, true);
const TestCase kTestCases[] = {
// Reauth URL, not sync username.
@@ -176,8 +177,10 @@ TEST_F(CredentialsFilterTest, FilterResults_DisallowSyncOnReauth) {
}
TEST_F(CredentialsFilterTest, FilterResults_DisallowSync) {
- base::CommandLine* command_line = base::CommandLine::ForCurrentProcess();
- command_line->AppendSwitch(switches::kDisallowAutofillSyncCredential);
+ // Both features are kept enabled, should cause sync credential to be
+ // filtered.
+ EnableFeature(features::kProtectSyncCredential, true, false);
+ EnableFeature(features::kProtectSyncCredentialOnReauth, true, true);
const TestCase kTestCases[] = {
// Reauth URL, not sync username.
@@ -248,9 +251,10 @@ TEST_F(CredentialsFilterTest, ShouldSave_SyncCredential_NotSyncingPasswords) {
}
TEST_F(CredentialsFilterTest, ShouldFilterOneForm) {
- // Adding disallow switch should cause sync credential to be filtered.
- base::CommandLine* command_line = base::CommandLine::ForCurrentProcess();
- command_line->AppendSwitch(switches::kDisallowAutofillSyncCredential);
+ // Both features are kept enabled, should cause sync credential to be
+ // filtered.
+ EnableFeature(features::kProtectSyncCredential, true, false);
+ EnableFeature(features::kProtectSyncCredentialOnReauth, true, true);
ScopedVector<autofill::PasswordForm> results;
results.push_back(new PasswordForm(SimpleGaiaForm("test1@gmail.com")));

Powered by Google App Engine
This is Rietveld 408576698